@@ -10,7 +10,9 @@ import tempfile
 import itertools
 import subprocess
 from time import time, sleep
+
 from setproctitle import setproctitle
+
 from kuyruk import __version__
 from kuyruk.process import KuyrukProcess
 
@@ -58,8 +60,9 @@ class Master(KuyrukProcess):
 
     def shutdown_workers(self, kill=False):
         """Sends shutdown signal to all workers."""
+        kill_signal = signal.SIGKILL if kill else signal.SIGTERM
         for worker in self.workers:
-            os.kill(worker.pid, signal.SIGKILL if kill else signal.SIGTERM)
+            os.kill(worker.pid, kill_signal)
 
     def wait_for_workers(self):
         """Loops until any of the self.workers is alive.
